pub enum EventType {
BlockAdded = 0,
VirtualChainChanged = 1,
FinalityConflict = 2,
FinalityConflictResolved = 3,
UtxosChanged = 4,
SinkBlueScoreChanged = 5,
VirtualDaaScoreChanged = 6,
PruningPointUtxoSetOverride = 7,
NewBlockTemplate = 8,
}Expand description
Event type classifying subscriptions (see Scope) and notifications (see [Notification])
Note: This enum is central to the notification system. For supporting a new notification type, it is advised to start by adding a new variant here.
Variants
BlockAdded = 0
VirtualChainChanged = 1
FinalityConflict = 2
FinalityConflictResolved = 3
UtxosChanged = 4
SinkBlueScoreChanged = 5
VirtualDaaScoreChanged = 6
PruningPointUtxoSetOverride = 7
NewBlockTemplate = 8