Root

Struct Root 

pub struct Root<N>
where N: Notification,
{ /* private fields */ }
Root of a notification system

The Root receives new notifications via its notify function, transforms them according to its internal subscription scope and, when any, sends them through a channel.

It is a SubscriptionManager, so the notification scope can be dynamically configured according to the needs of the whole notification system.

Implementations

Source

impl<N> Root<N>
where N: Notification,

pub fn new(sender: Sender<N>) -> Self

pub fn with_context( sender: Sender<N>, subscription_context: SubscriptionContext, ) -> Self

pub fn send(&self, notification: N) -> Result<()>

pub fn close(&self) -> bool

pub fn is_closed(&self) -> bool

pub fn has_subscription(&self, event: EventType) -> bool