pub struct FinalityConflictResolvedScope {}Trait Implementations
Sourceimpl BorshDeserialize for FinalityConflictResolvedScope
impl BorshDeserialize for FinalityConflictResolvedScope
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for FinalityConflictResolvedScope
impl Clone for FinalityConflictResolvedScope
Sourcefn clone(&self) -> FinalityConflictResolvedScope
fn clone(&self) -> FinalityConflictResolvedScope
Returns a duplicate of the value. Read more
1.0.0fn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for FinalityConflictResolvedScope
impl Default for FinalityConflictResolvedScope
Sourcefn default() -> FinalityConflictResolvedScope
fn default() -> FinalityConflictResolvedScope
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for FinalityConflictResolvedScope
impl<'de> Deserialize<'de> for FinalityConflictResolvedScope
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<FinalityConflictResolvedScope> for Scope
impl From<FinalityConflictResolvedScope> for Scope
Sourcefn from(value: FinalityConflictResolvedScope) -> Self
fn from(value: FinalityConflictResolvedScope) -> Self
Converts to this type from the input type.
impl Eq for FinalityConflictResolvedScope
impl StructuralPartialEq for FinalityConflictResolvedScope