pub struct NewBlockTemplateScope {}Trait Implementations
Sourceimpl BorshDeserialize for NewBlockTemplateScope
impl BorshDeserialize for NewBlockTemplateScope
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for NewBlockTemplateScope
impl Clone for NewBlockTemplateScope
Sourcefn clone(&self) -> NewBlockTemplateScope
fn clone(&self) -> NewBlockTemplateScope
Returns a duplicate of the value. Read more
1.0.0fn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for NewBlockTemplateScope
impl Debug for NewBlockTemplateScope
Sourceimpl Default for NewBlockTemplateScope
impl Default for NewBlockTemplateScope
Sourcefn default() -> NewBlockTemplateScope
fn default() -> NewBlockTemplateScope
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for NewBlockTemplateScope
impl<'de> Deserialize<'de> for NewBlockTemplateScope
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Deserializer for NewBlockTemplateScope
impl Deserializer for NewBlockTemplateScope
Sourceimpl Display for NewBlockTemplateScope
impl Display for NewBlockTemplateScope
Sourceimpl From<NewBlockTemplateScope> for Scope
impl From<NewBlockTemplateScope> for Scope
Sourcefn from(value: NewBlockTemplateScope) -> Self
fn from(value: NewBlockTemplateScope) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for NewBlockTemplateScope
impl PartialEq for NewBlockTemplateScope
Sourceimpl Serialize for NewBlockTemplateScope
impl Serialize for NewBlockTemplateScope
Sourceimpl Serializer for NewBlockTemplateScope
impl Serializer for NewBlockTemplateScope
impl Eq for NewBlockTemplateScope
impl StructuralPartialEq for NewBlockTemplateScope