pub struct SinkBlueScoreChangedScope {}Trait Implementations
Sourceimpl BorshDeserialize for SinkBlueScoreChangedScope
impl BorshDeserialize for SinkBlueScoreChangedScope
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for SinkBlueScoreChangedScope
impl Clone for SinkBlueScoreChangedScope
Sourcefn clone(&self) -> SinkBlueScoreChangedScope
fn clone(&self) -> SinkBlueScoreChangedScope
Returns a duplicate of the value. Read more
1.0.0fn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SinkBlueScoreChangedScope
impl Debug for SinkBlueScoreChangedScope
Sourceimpl Default for SinkBlueScoreChangedScope
impl Default for SinkBlueScoreChangedScope
Sourcefn default() -> SinkBlueScoreChangedScope
fn default() -> SinkBlueScoreChangedScope
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for SinkBlueScoreChangedScope
impl<'de> Deserialize<'de> for SinkBlueScoreChangedScope
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for SinkBlueScoreChangedScope
impl Display for SinkBlueScoreChangedScope
Sourceimpl From<SinkBlueScoreChangedScope> for Scope
impl From<SinkBlueScoreChangedScope> for Scope
Sourcefn from(value: SinkBlueScoreChangedScope) -> Self
fn from(value: SinkBlueScoreChangedScope) -> Self
Converts to this type from the input type.
impl Eq for SinkBlueScoreChangedScope
impl StructuralPartialEq for SinkBlueScoreChangedScope