pub struct VirtualDaaScoreChangedScope {}Trait Implementations
Sourceimpl BorshDeserialize for VirtualDaaScoreChangedScope
impl BorshDeserialize for VirtualDaaScoreChangedScope
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for VirtualDaaScoreChangedScope
impl Clone for VirtualDaaScoreChangedScope
Sourcefn clone(&self) -> VirtualDaaScoreChangedScope
fn clone(&self) -> VirtualDaaScoreChangedScope
Returns a duplicate of the value. Read more
1.0.0fn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VirtualDaaScoreChangedScope
impl Debug for VirtualDaaScoreChangedScope
Sourceimpl Default for VirtualDaaScoreChangedScope
impl Default for VirtualDaaScoreChangedScope
Sourcefn default() -> VirtualDaaScoreChangedScope
fn default() -> VirtualDaaScoreChangedScope
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for VirtualDaaScoreChangedScope
impl<'de> Deserialize<'de> for VirtualDaaScoreChangedScope
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<VirtualDaaScoreChangedScope> for Scope
impl From<VirtualDaaScoreChangedScope> for Scope
Sourcefn from(value: VirtualDaaScoreChangedScope) -> Self
fn from(value: VirtualDaaScoreChangedScope) -> Self
Converts to this type from the input type.
impl Eq for VirtualDaaScoreChangedScope
impl StructuralPartialEq for VirtualDaaScoreChangedScope