pub struct Subscriber { /* private fields */ }Expand description
A subscriber handling subscription messages as Mutation and executing them into a SubscriptionManager
A subscriber has a set of enabled event type (see EventType). It only handles subscriptions
whose event type is enabled and drops all others.
A subscriber has a listener ID identifying its owner (usually a Notifier) as a listener of its manager
(usually also a Notifier).
Implementations
Sourceimpl Subscriber
impl Subscriber
pub fn new( name: &'static str, enabled_events: EventSwitches, subscription_manager: DynSubscriptionManager, listener_id: ListenerId, ) -> Self
pub fn handles_event_type(&self, event_type: EventType) -> bool
pub fn start(self: &Arc<Self>)
pub fn mutate(self: &Arc<Self>, mutation: Mutation) -> Result<()>
pub async fn join(self: &Arc<Self>) -> Result<()>
pub fn close(&self)