pub struct MutationOutcome {
pub mutated: Option<DynSubscription>,
pub mutations: Vec<Mutation>,
}Expand description
The result of applying a Mutation to a DynSubscription
Fields
mutated: Option<DynSubscription>Optional new mutated subscription state
mutations: Vec<Mutation>Mutations applied to the DynSubscription
Implementations
Sourceimpl MutationOutcome
impl MutationOutcome
pub fn new() -> Self
pub fn with_mutations(mutations: Vec<Mutation>) -> Self
pub fn with_mutated(mutated: DynSubscription, mutations: Vec<Mutation>) -> Self
Sourcepub fn apply_to(self, target: &mut DynSubscription) -> Self
pub fn apply_to(self, target: &mut DynSubscription) -> Self
Updates target to the mutated state if any, otherwise leave target as is.
pub fn has_new_state(&self) -> bool
pub fn has_changes(&self) -> bool